@@ -1,4 +1,4 @@
-dfrom django import template
+from django import template
 import simplejson as json
 import datetime
 from knockout_modeler.ko import ko, koData, koModel, get_fields
